from pydantic import Field, BeforeValidator
from typing import Annotated
from .base import CommandType, BaseCommand


class StartRecording(BaseCommand):
    recording_id: str = Field(description="The ID of the recording to start")
    type: Annotated[
        CommandType, BeforeValidator(lambda _: CommandType.START_RECORDING)
    ] = Field(init=False, default=CommandType.START_RECORDING, frozen=True)



from pydantic import Field, BeforeValidator
from typing import Annotated
from .base import CommandType, BaseCommand


class StopRecording(BaseCommand):
    type: Annotated[
        CommandType, BeforeValidator(lambda _: CommandType.STOP_RECORDING)
    ] = Field(init=False, default=CommandType.STOP_RECORDING, frozen=True)



from .join_meet import JoinMeet
from .login_google_account import LoginGoogleAccount
from .stop_recording import StopRecording
from .start_recording import StartRecording
from .publish_recording import PublishRecording
from .leave_meet import LeaveMeet

__all__ = [
    "LeaveMeet",
    "JoinMeet",
    "LoginGoogleAccount",
    "StopRecording",
    "StartRecording",
    "PublishRecording",
]



from pydantic import Field, BeforeValidator
from typing import Annotated
from .base import CommandType, BaseCommand


class PublishRecording(BaseCommand):
    recording_id: str = Field(
        description="The ID of the recording to be published (passed in start_recording command)",
    )
    s3_key: str | None = Field(
        examples=["gmeet/recording.flac"],
        description="Final recording name to be published, if not provided, the name will be taken from the recording_id",
    )
    type: Annotated[
        CommandType, BeforeValidator(lambda _: CommandType.PUBLISH_RECORDING)
    ] = Field(init=False, default=CommandType.PUBLISH_RECORDING, frozen=True)



from enum import Enum
from pydantic import BaseModel, Field
from datetime import datetime


class BotState(Enum):
    def __new__(cls, label: str):
        obj = object.__new__(cls)
        obj._value_ = len(cls.__members__), label
        return obj

    INITIALIZING = "init"
    READY = "ready"

    LOGGED_GOOGLE = "logged_google"
    WAITING_INVITATION_CONFIRMATION = "waiting_invitation_confirmation"
    CONNECTED_MEET = "connected_meet"

    RECORDING_STARTED = "recording_started"
    RECORDING_STOPPED = "recording_stopped"
    RECORDING_PUBLISHED = "recording_published"

    DEAD = "dead"

    @property
    def code(self) -> int:
        return self.value[0]

    @property
    def label(self) -> str:
        return self.value[1]

    def __str__(self):
        return self.label

    @classmethod
    def from_code(cls, code: int) -> "BotState":
        for state in cls:
            if state.code == code:
                return state
        raise ValueError(f"Invalid status code: {code}")


class StateMessage(BaseModel):
    state: BotState = Field(..., description="The current state of the bot")
    timestamp: datetime = Field(
        default_factory=datetime.now,
        description="The timestamp when the state was updated",
    )



from pydantic import Field, BeforeValidator
from typing import Annotated
from .base import CommandType, BaseCommand


class LeaveMeet(BaseCommand):
    type: Annotated[CommandType, BeforeValidator(lambda _: CommandType.LEAVE_MEET)] = (
        Field(init=False, default=CommandType.LEAVE_MEET, frozen=True)
    )



from enum import StrEnum


class CommandType(StrEnum):
    LOGIN_GOOGLE_ACCOUNT = "login_google_account"
    JOIN_MEET = "join_meet"
    START_RECORDING = "start_recording"
    STOP_RECORDING = "stop_recording"
    PUBLISH_RECORDING = "publish_recording"
    LEAVE_MEET = "leave_meet"
